# Causal Tracer

Causal trace plots for transformer language models

## About

This library is based heavily on causal tracing code from [ROME](https://rome.baulab.info/), and package and improves on their excellent work.
